@@ -366,8 +366,9 @@ class MaskedInput(VSplit):
     ):
         self._mask = mask
         self._placeholder = placeholder
-        self._accept_handler = accept_handler
+        
         self._value = value
+        self.accept_handler = accept_handler
 
         self.current_position = 0
         self._components = []
@@ -429,11 +430,13 @@ class MaskedInput(VSplit):
 
 class DateRange(HSplit):
 
-    def __init__(self, from_label='From: ', to_label='  to: ', style=None):
+    def __init__(self, from_label='From: ', to_label='  to: ', accept_handler=None, style=None):
 
         self._from = MaskedInput(mask='____-__-__', allowed_chars=string.digits, style=style)
         self._to = MaskedInput(mask='____-__-__', allowed_chars=string.digits, style=style)
 
+        self.accept_handler = accept_handler
+
         # Key bindings.
         kb = KeyBindings()
 
